/********************************************************************************
** Form generated from reading UI file 'mainwindow.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAINWINDOW_H
#define UI_MAINWINDOW_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QMenu>
#include <QtWidgets/QMenuBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_MainWindow
{
public:
    QAction *actionQuit;
    QAction *actionSave_As;
    QAction *actionLoad;
    QAction *actionAbout;
    QWidget *centralWidget;
    QPushButton *applyButton;
    QTabWidget *tabWidget;
    QWidget *tab_3;
    QComboBox *sampleFormatCombo;
    QLabel *label_5;
    QLabel *label_6;
    QComboBox *channelConfigCombo;
    QComboBox *sampleRateCombo;
    QLabel *label_7;
    QLabel *label_14;
    QComboBox *stereoModeCombo;
    QGroupBox *groupBox;
    QGroupBox *groupBox_3;
    QWidget *widget;
    QLabel *label_11;
    QSlider *periodCountSlider;
    QLineEdit *periodCountEdit;
    QWidget *widget_2;
    QSlider *periodSizeSlider;
    QLabel *label_10;
    QLineEdit *periodSizeEdit;
    QComboBox *stereoEncodingComboBox;
    QLabel *label_19;
    QLabel *label_30;
    QComboBox *ambiFormatComboBox;
    QCheckBox *outputLimiterCheckBox;
    QCheckBox *outputDitherCheckBox;
    QGroupBox *groupBox_4;
    QLabel *resamplerLabel;
    QSlider *resamplerSlider;
    QLabel *label_9;
    QLabel *label_15;
    QWidget *tab_6;
    QCheckBox *decoderHQModeCheckBox;
    QCheckBox *decoderDistCompCheckBox;
    QGroupBox *groupBox_8;
    QLineEdit *decoderQuadLineEdit;
    QLabel *label_25;
    QPushButton *decoderQuadButton;
    QLineEdit *decoder51LineEdit;
    QPushButton *decoder51Button;
    QLabel *label_26;
    QLabel *label_28;
    QLineEdit *decoder61LineEdit;
    QPushButton *decoder61Button;
    QPushButton *decoder71Button;
    QLineEdit *decoder71LineEdit;
    QLabel *label_29;
    QLabel *label_33;
    QLineEdit *decoder3D71LineEdit;
    QPushButton *decoder3D71Button;
    QCheckBox *decoderNFEffectsCheckBox;
    QWidget *widget_3;
    QLabel *label_27;
    QDoubleSpinBox *decoderSpeakerDistSpinBox;
    QWidget *tab_5;
    QGroupBox *groupBox_2;
    QGroupBox *groupBox_6;
    QListWidget *hrtfFileList;
    QPushButton *hrtfAddButton;
    QCheckBox *defaultHrtfPathsCheckBox;
    QPushButton *hrtfRemoveButton;
    QLabel *label_12;
    QComboBox *preferredHrtfComboBox;
    QGroupBox *groupBox_9;
    QLabel *label_31;
    QLabel *label_32;
    QSlider *hrtfmodeSlider;
    QLabel *hrtfmodeLabel;
    QWidget *tab;
    QListWidget *backendListWidget;
    QStackedWidget *backendStackedWidget;
    QWidget *page;
    QCheckBox *backendCheckBox;
    QListWidget *disabledBackendList;
    QListWidget *enabledBackendList;
    QLabel *label_2;
    QLabel *label;
    QWidget *page_1;
    QCheckBox *pwireAssumeAudioCheckBox;
    QCheckBox *pwireRtMixCheckBox;
    QWidget *page_2;
    QCheckBox *wasapiResamplerCheckBox;
    QWidget *page_8;
    QCheckBox *pulseAutospawnCheckBox;
    QCheckBox *pulseAllowMovesCheckBox;
    QCheckBox *pulseFixRateCheckBox;
    QCheckBox *pulseAdjLatencyCheckBox;
    QWidget *page_7;
    QCheckBox *jackAutospawnCheckBox;
    QGroupBox *groupBox_7;
    QLineEdit *jackBufferSizeLine;
    QSlider *jackBufferSizeSlider;
    QCheckBox *jackConnectPortsCheckBox;
    QCheckBox *jackRtMixCheckBox;
    QWidget *page_3;
    QLabel *label_17;
    QLineEdit *alsaDefaultDeviceLine;
    QLabel *label_18;
    QLineEdit *alsaDefaultCaptureLine;
    QCheckBox *alsaResamplerCheckBox;
    QCheckBox *alsaMmapCheckBox;
    QWidget *page_4;
    QLabel *label_20;
    QLineEdit *ossDefaultDeviceLine;
    QLabel *label_21;
    QLineEdit *ossDefaultCaptureLine;
    QPushButton *ossPlaybackPushButton;
    QPushButton *ossCapturePushButton;
    QWidget *page_5;
    QLineEdit *solarisDefaultDeviceLine;
    QLabel *label_22;
    QPushButton *solarisPlaybackPushButton;
    QWidget *page_6;
    QLabel *label_23;
    QLineEdit *waveOutputLine;
    QLabel *label_24;
    QPushButton *waveOutputButton;
    QCheckBox *waveBFormatCheckBox;
    QWidget *tab_2;
    QLineEdit *srcCountLineEdit;
    QLabel *label_3;
    QLabel *label_4;
    QLineEdit *effectSlotLineEdit;
    QLabel *label_8;
    QLineEdit *srcSendLineEdit;
    QGroupBox *cpuExtGroupBox;
    QCheckBox *enableSSECheckBox;
    QCheckBox *enableSSE2CheckBox;
    QCheckBox *enableNeonCheckBox;
    QCheckBox *enableSSE41CheckBox;
    QCheckBox *enableSSE3CheckBox;
    QLabel *cpuExtDisabledLabel;
    QWidget *tab_4;
    QGroupBox *groupBox_5;
    QCheckBox *enableEaxReverbCheck;
    QCheckBox *enableStdReverbCheck;
    QCheckBox *enableChorusCheck;
    QCheckBox *enableDistortionCheck;
    QCheckBox *enableEchoCheck;
    QCheckBox *enableEqualizerCheck;
    QCheckBox *enableFlangerCheck;
    QCheckBox *enableModulatorCheck;
    QCheckBox *enableDedicatedCheck;
    QCheckBox *enableCompressorCheck;
    QCheckBox *enablePitchShifterCheck;
    QCheckBox *enableFrequencyShifterCheck;
    QCheckBox *enableAutowahCheck;
    QCheckBox *enableVocalMorpherCheck;
    QLabel *label_13;
    QComboBox *defaultReverbComboBox;
    QCheckBox *enableEaxCheck;
    QPushButton *closeCancelButton;
    QMenuBar *menuBar;
    QMenu *menuFile;
    QMenu *menuHelp;

    void setupUi(QMainWindow *MainWindow)
    {
        if (MainWindow->objectName().isEmpty())
            MainWindow->setObjectName(QStringLiteral("MainWindow"));
        MainWindow->resize(564, 469);
        MainWindow->setMinimumSize(QSize(564, 460));
        QIcon icon;
        QString iconThemeName = QStringLiteral("preferences-desktop-sound");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        MainWindow->setWindowIcon(icon);
        actionQuit = new QAction(MainWindow);
        actionQuit->setObjectName(QStringLiteral("actionQuit"));
        QIcon icon1;
        iconThemeName = QStringLiteral("application-exit");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionQuit->setIcon(icon1);
        actionSave_As = new QAction(MainWindow);
        actionSave_As->setObjectName(QStringLiteral("actionSave_As"));
        QIcon icon2;
        iconThemeName = QStringLiteral("document-save-as");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon2 = QIcon::fromTheme(iconThemeName);
        } else {
            icon2.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionSave_As->setIcon(icon2);
        actionLoad = new QAction(MainWindow);
        actionLoad->setObjectName(QStringLiteral("actionLoad"));
        QIcon icon3;
        iconThemeName = QStringLiteral("document-open");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon3 = QIcon::fromTheme(iconThemeName);
        } else {
            icon3.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionLoad->setIcon(icon3);
        actionAbout = new QAction(MainWindow);
        actionAbout->setObjectName(QStringLiteral("actionAbout"));
        centralWidget = new QWidget(MainWindow);
        centralWidget->setObjectName(QStringLiteral("centralWidget"));
        applyButton = new QPushButton(centralWidget);
        applyButton->setObjectName(QStringLiteral("applyButton"));
        applyButton->setGeometry(QRect(470, 405, 81, 31));
        QIcon icon4;
        iconThemeName = QStringLiteral("dialog-ok-apply");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon4 = QIcon::fromTheme(iconThemeName);
        } else {
            icon4.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        applyButton->setIcon(icon4);
        tabWidget = new QTabWidget(centralWidget);
        tabWidget->setObjectName(QStringLiteral("tabWidget"));
        tabWidget->setGeometry(QRect(10, 0, 541, 401));
        tab_3 = new QWidget();
        tab_3->setObjectName(QStringLiteral("tab_3"));
        sampleFormatCombo = new QComboBox(tab_3);
        sampleFormatCombo->setObjectName(QStringLiteral("sampleFormatCombo"));
        sampleFormatCombo->setGeometry(QRect(110, 50, 80, 31));
        sampleFormatCombo->setSizeAdjustPolicy(QComboBox::AdjustToContents);
        label_5 = new QLabel(tab_3);
        label_5->setObjectName(QStringLiteral("label_5"));
        label_5->setGeometry(QRect(0, 50, 101, 31));
        label_5->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_6 = new QLabel(tab_3);
        label_6->setObjectName(QStringLiteral("label_6"));
        label_6->setGeometry(QRect(0, 20, 101, 31));
        label_6->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        channelConfigCombo = new QComboBox(tab_3);
        channelConfigCombo->setObjectName(QStringLiteral("channelConfigCombo"));
        channelConfigCombo->setGeometry(QRect(110, 20, 80, 31));
        channelConfigCombo->setSizeAdjustPolicy(QComboBox::AdjustToContents);
        sampleRateCombo = new QComboBox(tab_3);
        sampleRateCombo->setObjectName(QStringLiteral("sampleRateCombo"));
        sampleRateCombo->setGeometry(QRect(380, 20, 100, 31));
        sampleRateCombo->setEditable(true);
        sampleRateCombo->setInsertPolicy(QComboBox::NoInsert);
        sampleRateCombo->setSizeAdjustPolicy(QComboBox::AdjustToContents);
        label_7 = new QLabel(tab_3);
        label_7->setObjectName(QStringLiteral("label_7"));
        label_7->setGeometry(QRect(290, 20, 81, 31));
        label_7->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_14 = new QLabel(tab_3);
        label_14->setObjectName(QStringLiteral("label_14"));
        label_14->setGeometry(QRect(290, 50, 81, 31));
        label_14->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        stereoModeCombo = new QComboBox(tab_3);
        stereoModeCombo->setObjectName(QStringLiteral("stereoModeCombo"));
        stereoModeCombo->setGeometry(QRect(380, 50, 101, 31));
        groupBox = new QGroupBox(tab_3);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        groupBox->setGeometry(QRect(-11, 180, 551, 201));
        groupBox->setAlignment(Qt::AlignCenter);
        groupBox_3 = new QGroupBox(groupBox);
        groupBox_3->setObjectName(QStringLiteral("groupBox_3"));
        groupBox_3->setGeometry(QRect(20, 30, 511, 81));
        groupBox_3->setAlignment(Qt::AlignCenter);
        widget = new QWidget(groupBox_3);
        widget->setObjectName(QStringLiteral("widget"));
        widget->setGeometry(QRect(260, 20, 241, 51));
        label_11 = new QLabel(widget);
        label_11->setObjectName(QStringLiteral("label_11"));
        label_11->setGeometry(QRect(60, 0, 161, 21));
        label_11->setAlignment(Qt::AlignCenter);
        periodCountSlider = new QSlider(widget);
        periodCountSlider->setObjectName(QStringLiteral("periodCountSlider"));
        periodCountSlider->setGeometry(QRect(99, 20, 141, 21));
        periodCountSlider->setMinimum(1);
        periodCountSlider->setMaximum(16);
        periodCountSlider->setSingleStep(1);
        periodCountSlider->setPageStep(2);
        periodCountSlider->setValue(1);
        periodCountSlider->setTracking(true);
        periodCountSlider->setOrientation(Qt::Horizontal);
        periodCountSlider->setTickPosition(QSlider::TicksBelow);
        periodCountSlider->setTickInterval(1);
        periodCountEdit = new QLineEdit(widget);
        periodCountEdit->setObjectName(QStringLiteral("periodCountEdit"));
        periodCountEdit->setGeometry(QRect(40, 20, 51, 21));
        widget_2 = new QWidget(groupBox_3);
        widget_2->setObjectName(QStringLiteral("widget_2"));
        widget_2->setGeometry(QRect(10, 20, 241, 51));
        periodSizeSlider = new QSlider(widget_2);
        periodSizeSlider->setObjectName(QStringLiteral("periodSizeSlider"));
        periodSizeSlider->setGeometry(QRect(60, 20, 191, 21));
        periodSizeSlider->setMinimum(63);
        periodSizeSlider->setMaximum(8192);
        periodSizeSlider->setSingleStep(1);
        periodSizeSlider->setPageStep(1024);
        periodSizeSlider->setValue(63);
        periodSizeSlider->setTracking(true);
        periodSizeSlider->setOrientation(Qt::Horizontal);
        periodSizeSlider->setTickPosition(QSlider::TicksBelow);
        periodSizeSlider->setTickInterval(512);
        label_10 = new QLabel(widget_2);
        label_10->setObjectName(QStringLiteral("label_10"));
        label_10->setGeometry(QRect(10, 0, 201, 21));
        label_10->setAlignment(Qt::AlignCenter);
        periodSizeEdit = new QLineEdit(widget_2);
        periodSizeEdit->setObjectName(QStringLiteral("periodSizeEdit"));
        periodSizeEdit->setGeometry(QRect(0, 20, 51, 21));
        stereoEncodingComboBox = new QComboBox(groupBox);
        stereoEncodingComboBox->setObjectName(QStringLiteral("stereoEncodingComboBox"));
        stereoEncodingComboBox->setGeometry(QRect(130, 120, 111, 31));
        label_19 = new QLabel(groupBox);
        label_19->setObjectName(QStringLiteral("label_19"));
        label_19->setGeometry(QRect(20, 120, 101, 31));
        label_19->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_30 = new QLabel(groupBox);
        label_30->setObjectName(QStringLiteral("label_30"));
        label_30->setGeometry(QRect(260, 120, 121, 31));
        label_30->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        ambiFormatComboBox = new QComboBox(groupBox);
        ambiFormatComboBox->setObjectName(QStringLiteral("ambiFormatComboBox"));
        ambiFormatComboBox->setGeometry(QRect(390, 120, 131, 31));
        outputLimiterCheckBox = new QCheckBox(groupBox);
        outputLimiterCheckBox->setObjectName(QStringLiteral("outputLimiterCheckBox"));
        outputLimiterCheckBox->setGeometry(QRect(30, 160, 231, 20));
        outputLimiterCheckBox->setTristate(true);
        outputDitherCheckBox = new QCheckBox(groupBox);
        outputDitherCheckBox->setObjectName(QStringLiteral("outputDitherCheckBox"));
        outputDitherCheckBox->setGeometry(QRect(270, 160, 261, 21));
        outputDitherCheckBox->setTristate(true);
        groupBox_4 = new QGroupBox(tab_3);
        groupBox_4->setObjectName(QStringLiteral("groupBox_4"));
        groupBox_4->setGeometry(QRect(60, 90, 421, 81));
        groupBox_4->setAlignment(Qt::AlignCenter);
        resamplerLabel = new QLabel(groupBox_4);
        resamplerLabel->setObjectName(QStringLiteral("resamplerLabel"));
        resamplerLabel->setGeometry(QRect(50, 50, 321, 21));
        resamplerLabel->setAlignment(Qt::AlignCenter);
        resamplerSlider = new QSlider(groupBox_4);
        resamplerSlider->setObjectName(QStringLiteral("resamplerSlider"));
        resamplerSlider->setGeometry(QRect(80, 30, 251, 23));
        resamplerSlider->setOrientation(Qt::Horizontal);
        label_9 = new QLabel(groupBox_4);
        label_9->setObjectName(QStringLiteral("label_9"));
        label_9->setGeometry(QRect(20, 30, 51, 21));
        label_9->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_15 = new QLabel(groupBox_4);
        label_15->setObjectName(QStringLiteral("label_15"));
        label_15->setGeometry(QRect(340, 30, 51, 21));
        tabWidget->addTab(tab_3, QString());
        tab_6 = new QWidget();
        tab_6->setObjectName(QStringLiteral("tab_6"));
        decoderHQModeCheckBox = new QCheckBox(tab_6);
        decoderHQModeCheckBox->setObjectName(QStringLiteral("decoderHQModeCheckBox"));
        decoderHQModeCheckBox->setGeometry(QRect(30, 20, 181, 21));
        decoderHQModeCheckBox->setLayoutDirection(Qt::RightToLeft);
        decoderHQModeCheckBox->setTristate(true);
        decoderDistCompCheckBox = new QCheckBox(tab_6);
        decoderDistCompCheckBox->setObjectName(QStringLiteral("decoderDistCompCheckBox"));
        decoderDistCompCheckBox->setGeometry(QRect(30, 50, 181, 21));
        decoderDistCompCheckBox->setLayoutDirection(Qt::RightToLeft);
        decoderDistCompCheckBox->setTristate(true);
        groupBox_8 = new QGroupBox(tab_6);
        groupBox_8->setObjectName(QStringLiteral("groupBox_8"));
        groupBox_8->setGeometry(QRect(-10, 140, 551, 231));
        groupBox_8->setAlignment(Qt::AlignCenter);
        decoderQuadLineEdit = new QLineEdit(groupBox_8);
        decoderQuadLineEdit->setObjectName(QStringLiteral("decoderQuadLineEdit"));
        decoderQuadLineEdit->setGeometry(QRect(130, 30, 301, 25));
        label_25 = new QLabel(groupBox_8);
        label_25->setObjectName(QStringLiteral("label_25"));
        label_25->setGeometry(QRect(20, 30, 101, 25));
        label_25->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        decoderQuadButton = new QPushButton(groupBox_8);
        decoderQuadButton->setObjectName(QStringLiteral("decoderQuadButton"));
        decoderQuadButton->setGeometry(QRect(440, 30, 91, 25));
        decoder51LineEdit = new QLineEdit(groupBox_8);
        decoder51LineEdit->setObjectName(QStringLiteral("decoder51LineEdit"));
        decoder51LineEdit->setGeometry(QRect(130, 70, 301, 25));
        decoder51Button = new QPushButton(groupBox_8);
        decoder51Button->setObjectName(QStringLiteral("decoder51Button"));
        decoder51Button->setGeometry(QRect(440, 70, 91, 25));
        label_26 = new QLabel(groupBox_8);
        label_26->setObjectName(QStringLiteral("label_26"));
        label_26->setGeometry(QRect(20, 70, 101, 25));
        label_26->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_28 = new QLabel(groupBox_8);
        label_28->setObjectName(QStringLiteral("label_28"));
        label_28->setGeometry(QRect(20, 110, 101, 25));
        label_28->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        decoder61LineEdit = new QLineEdit(groupBox_8);
        decoder61LineEdit->setObjectName(QStringLiteral("decoder61LineEdit"));
        decoder61LineEdit->setGeometry(QRect(130, 110, 301, 25));
        decoder61Button = new QPushButton(groupBox_8);
        decoder61Button->setObjectName(QStringLiteral("decoder61Button"));
        decoder61Button->setGeometry(QRect(440, 110, 91, 25));
        decoder71Button = new QPushButton(groupBox_8);
        decoder71Button->setObjectName(QStringLiteral("decoder71Button"));
        decoder71Button->setGeometry(QRect(440, 150, 91, 25));
        decoder71LineEdit = new QLineEdit(groupBox_8);
        decoder71LineEdit->setObjectName(QStringLiteral("decoder71LineEdit"));
        decoder71LineEdit->setGeometry(QRect(130, 150, 301, 25));
        label_29 = new QLabel(groupBox_8);
        label_29->setObjectName(QStringLiteral("label_29"));
        label_29->setGeometry(QRect(20, 150, 101, 25));
        label_29->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_33 = new QLabel(groupBox_8);
        label_33->setObjectName(QStringLiteral("label_33"));
        label_33->setGeometry(QRect(20, 190, 101, 25));
        label_33->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        decoder3D71LineEdit = new QLineEdit(groupBox_8);
        decoder3D71LineEdit->setObjectName(QStringLiteral("decoder3D71LineEdit"));
        decoder3D71LineEdit->setGeometry(QRect(130, 190, 301, 25));
        decoder3D71Button = new QPushButton(groupBox_8);
        decoder3D71Button->setObjectName(QStringLiteral("decoder3D71Button"));
        decoder3D71Button->setGeometry(QRect(440, 190, 91, 25));
        decoderNFEffectsCheckBox = new QCheckBox(tab_6);
        decoderNFEffectsCheckBox->setObjectName(QStringLiteral("decoderNFEffectsCheckBox"));
        decoderNFEffectsCheckBox->setGeometry(QRect(30, 80, 181, 21));
        decoderNFEffectsCheckBox->setLayoutDirection(Qt::RightToLeft);
        decoderNFEffectsCheckBox->setTristate(true);
        widget_3 = new QWidget(tab_6);
        widget_3->setObjectName(QStringLiteral("widget_3"));
        widget_3->setGeometry(QRect(30, 110, 471, 21));
        label_27 = new QLabel(widget_3);
        label_27->setObjectName(QStringLiteral("label_27"));
        label_27->setGeometry(QRect(45, 0, 111, 21));
        label_27->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        decoderSpeakerDistSpinBox = new QDoubleSpinBox(widget_3);
        decoderSpeakerDistSpinBox->setObjectName(QStringLiteral("decoderSpeakerDistSpinBox"));
        decoderSpeakerDistSpinBox->setGeometry(QRect(165, 0, 101, 21));
        decoderSpeakerDistSpinBox->setDecimals(2);
        decoderSpeakerDistSpinBox->setMinimum(0.1);
        decoderSpeakerDistSpinBox->setMaximum(10);
        decoderSpeakerDistSpinBox->setSingleStep(0.01);
        decoderSpeakerDistSpinBox->setValue(1);
        tabWidget->addTab(tab_6, QString());
        tab_5 = new QWidget();
        tab_5->setObjectName(QStringLiteral("tab_5"));
        groupBox_2 = new QGroupBox(tab_5);
        groupBox_2->setObjectName(QStringLiteral("groupBox_2"));
        groupBox_2->setGeometry(QRect(-10, 200, 551, 181));
        groupBox_2->setAlignment(Qt::AlignCenter);
        groupBox_2->setCheckable(false);
        groupBox_2->setChecked(false);
        groupBox_6 = new QGroupBox(groupBox_2);
        groupBox_6->setObjectName(QStringLiteral("groupBox_6"));
        groupBox_6->setGeometry(QRect(20, 30, 511, 141));
        groupBox_6->setAlignment(Qt::AlignCenter);
        hrtfFileList = new QListWidget(groupBox_6);
        hrtfFileList->setObjectName(QStringLiteral("hrtfFileList"));
        hrtfFileList->setGeometry(QRect(20, 20, 391, 81));
        hrtfFileList->setDragDropMode(QAbstractItemView::InternalMove);
        hrtfFileList->setAlternatingRowColors(true);
        hrtfFileList->setSelectionMode(QAbstractItemView::ExtendedSelection);
        hrtfFileList->setTextElideMode(Qt::ElideNone);
        hrtfAddButton = new QPushButton(groupBox_6);
        hrtfAddButton->setObjectName(QStringLiteral("hrtfAddButton"));
        hrtfAddButton->setGeometry(QRect(420, 20, 81, 21));
        QIcon icon5;
        iconThemeName = QStringLiteral("list-add");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon5 = QIcon::fromTheme(iconThemeName);
        } else {
            icon5.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        hrtfAddButton->setIcon(icon5);
        hrtfAddButton->setFlat(false);
        defaultHrtfPathsCheckBox = new QCheckBox(groupBox_6);
        defaultHrtfPathsCheckBox->setObjectName(QStringLiteral("defaultHrtfPathsCheckBox"));
        defaultHrtfPathsCheckBox->setGeometry(QRect(180, 110, 151, 21));
        defaultHrtfPathsCheckBox->setChecked(true);
        hrtfRemoveButton = new QPushButton(groupBox_6);
        hrtfRemoveButton->setObjectName(QStringLiteral("hrtfRemoveButton"));
        hrtfRemoveButton->setGeometry(QRect(420, 50, 81, 21));
        QIcon icon6;
        iconThemeName = QStringLiteral("list-remove");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon6 = QIcon::fromTheme(iconThemeName);
        } else {
            icon6.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        hrtfRemoveButton->setIcon(icon6);
        label_12 = new QLabel(tab_5);
        label_12->setObjectName(QStringLiteral("label_12"));
        label_12->setGeometry(QRect(30, 20, 91, 31));
        label_12->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        preferredHrtfComboBox = new QComboBox(tab_5);
        preferredHrtfComboBox->setObjectName(QStringLiteral("preferredHrtfComboBox"));
        preferredHrtfComboBox->setGeometry(QRect(130, 20, 161, 31));
        groupBox_9 = new QGroupBox(tab_5);
        groupBox_9->setObjectName(QStringLiteral("groupBox_9"));
        groupBox_9->setGeometry(QRect(50, 100, 441, 81));
        label_31 = new QLabel(groupBox_9);
        label_31->setObjectName(QStringLiteral("label_31"));
        label_31->setGeometry(QRect(20, 30, 51, 21));
        label_31->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_32 = new QLabel(groupBox_9);
        label_32->setObjectName(QStringLiteral("label_32"));
        label_32->setGeometry(QRect(340, 30, 51, 21));
        hrtfmodeSlider = new QSlider(groupBox_9);
        hrtfmodeSlider->setObjectName(QStringLiteral("hrtfmodeSlider"));
        hrtfmodeSlider->setGeometry(QRect(80, 30, 251, 21));
        hrtfmodeSlider->setOrientation(Qt::Horizontal);
        hrtfmodeLabel = new QLabel(groupBox_9);
        hrtfmodeLabel->setObjectName(QStringLiteral("hrtfmodeLabel"));
        hrtfmodeLabel->setGeometry(QRect(50, 50, 321, 21));
        hrtfmodeLabel->setAlignment(Qt::AlignCenter);
        tabWidget->addTab(tab_5, QString());
        tab = new QWidget();
        tab->setObjectName(QStringLiteral("tab"));
        backendListWidget = new QListWidget(tab);
        new QListWidgetItem(backendListWidget);
        new QListWidgetItem(backendListWidget);
        new QListWidgetItem(backendListWidget);
        new QListWidgetItem(backendListWidget);
        new QListWidgetItem(backendListWidget);
        new QListWidgetItem(backendListWidget);
        new QListWidgetItem(backendListWidget);
        new QListWidgetItem(backendListWidget);
        new QListWidgetItem(backendListWidget);
        backendListWidget->setObjectName(QStringLiteral("backendListWidget"));
        backendListWidget->setGeometry(QRect(0, 11, 111, 361));
        backendListWidget->setAlternatingRowColors(true);
        backendStackedWidget = new QStackedWidget(tab);
        backendStackedWidget->setObjectName(QStringLiteral("backendStackedWidget"));
        backendStackedWidget->setGeometry(QRect(110, 10, 421, 361));
        page = new QWidget();
        page->setObjectName(QStringLiteral("page"));
        backendCheckBox = new QCheckBox(page);
        backendCheckBox->setObjectName(QStringLiteral("backendCheckBox"));
        backendCheckBox->setGeometry(QRect(20, 190, 391, 21));
        backendCheckBox->setChecked(true);
        disabledBackendList = new QListWidget(page);
        disabledBackendList->setObjectName(QStringLiteral("disabledBackendList"));
        disabledBackendList->setGeometry(QRect(220, 30, 191, 151));
        enabledBackendList = new QListWidget(page);
        enabledBackendList->setObjectName(QStringLiteral("enabledBackendList"));
        enabledBackendList->setGeometry(QRect(20, 30, 191, 151));
        enabledBackendList->setDragDropMode(QAbstractItemView::InternalMove);
        label_2 = new QLabel(page);
        label_2->setObjectName(QStringLiteral("label_2"));
        label_2->setGeometry(QRect(230, 10, 171, 20));
        label = new QLabel(page);
        label->setObjectName(QStringLiteral("label"));
        label->setGeometry(QRect(30, 10, 171, 20));
        backendStackedWidget->addWidget(page);
        page_1 = new QWidget();
        page_1->setObjectName(QStringLiteral("page_1"));
        pwireAssumeAudioCheckBox = new QCheckBox(page_1);
        pwireAssumeAudioCheckBox->setObjectName(QStringLiteral("pwireAssumeAudioCheckBox"));
        pwireAssumeAudioCheckBox->setGeometry(QRect(20, 10, 161, 21));
        pwireAssumeAudioCheckBox->setTristate(true);
        pwireRtMixCheckBox = new QCheckBox(page_1);
        pwireRtMixCheckBox->setObjectName(QStringLiteral("pwireRtMixCheckBox"));
        pwireRtMixCheckBox->setGeometry(QRect(20, 40, 161, 21));
        pwireRtMixCheckBox->setTristate(true);
        backendStackedWidget->addWidget(page_1);
        page_2 = new QWidget();
        page_2->setObjectName(QStringLiteral("page_2"));
        wasapiResamplerCheckBox = new QCheckBox(page_2);
        wasapiResamplerCheckBox->setObjectName(QStringLiteral("wasapiResamplerCheckBox"));
        wasapiResamplerCheckBox->setGeometry(QRect(20, 10, 191, 21));
        wasapiResamplerCheckBox->setTristate(true);
        backendStackedWidget->addWidget(page_2);
        page_8 = new QWidget();
        page_8->setObjectName(QStringLiteral("page_8"));
        pulseAutospawnCheckBox = new QCheckBox(page_8);
        pulseAutospawnCheckBox->setObjectName(QStringLiteral("pulseAutospawnCheckBox"));
        pulseAutospawnCheckBox->setGeometry(QRect(20, 10, 141, 21));
        pulseAutospawnCheckBox->setTristate(true);
        pulseAllowMovesCheckBox = new QCheckBox(page_8);
        pulseAllowMovesCheckBox->setObjectName(QStringLiteral("pulseAllowMovesCheckBox"));
        pulseAllowMovesCheckBox->setGeometry(QRect(20, 40, 161, 21));
        pulseAllowMovesCheckBox->setTristate(true);
        pulseFixRateCheckBox = new QCheckBox(page_8);
        pulseFixRateCheckBox->setObjectName(QStringLiteral("pulseFixRateCheckBox"));
        pulseFixRateCheckBox->setGeometry(QRect(20, 70, 121, 21));
        pulseFixRateCheckBox->setTristate(true);
        pulseAdjLatencyCheckBox = new QCheckBox(page_8);
        pulseAdjLatencyCheckBox->setObjectName(QStringLiteral("pulseAdjLatencyCheckBox"));
        pulseAdjLatencyCheckBox->setGeometry(QRect(20, 100, 111, 21));
        pulseAdjLatencyCheckBox->setTristate(true);
        backendStackedWidget->addWidget(page_8);
        page_7 = new QWidget();
        page_7->setObjectName(QStringLiteral("page_7"));
        jackAutospawnCheckBox = new QCheckBox(page_7);
        jackAutospawnCheckBox->setObjectName(QStringLiteral("jackAutospawnCheckBox"));
        jackAutospawnCheckBox->setGeometry(QRect(20, 10, 141, 21));
        jackAutospawnCheckBox->setTristate(true);
        groupBox_7 = new QGroupBox(page_7);
        groupBox_7->setObjectName(QStringLiteral("groupBox_7"));
        groupBox_7->setGeometry(QRect(10, 110, 401, 80));
        groupBox_7->setAlignment(Qt::AlignCenter);
        jackBufferSizeLine = new QLineEdit(groupBox_7);
        jackBufferSizeLine->setObjectName(QStringLiteral("jackBufferSizeLine"));
        jackBufferSizeLine->setGeometry(QRect(320, 30, 71, 21));
        jackBufferSizeSlider = new QSlider(groupBox_7);
        jackBufferSizeSlider->setObjectName(QStringLiteral("jackBufferSizeSlider"));
        jackBufferSizeSlider->setGeometry(QRect(10, 30, 301, 21));
        jackBufferSizeSlider->setMaximum(13);
        jackBufferSizeSlider->setSingleStep(1);
        jackBufferSizeSlider->setPageStep(4);
        jackBufferSizeSlider->setOrientation(Qt::Horizontal);
        jackBufferSizeSlider->setTickPosition(QSlider::TicksBelow);
        jackBufferSizeSlider->setTickInterval(1);
        jackConnectPortsCheckBox = new QCheckBox(page_7);
        jackConnectPortsCheckBox->setObjectName(QStringLiteral("jackConnectPortsCheckBox"));
        jackConnectPortsCheckBox->setGeometry(QRect(20, 40, 141, 21));
        jackConnectPortsCheckBox->setTristate(true);
        jackRtMixCheckBox = new QCheckBox(page_7);
        jackRtMixCheckBox->setObjectName(QStringLiteral("jackRtMixCheckBox"));
        jackRtMixCheckBox->setGeometry(QRect(20, 70, 141, 21));
        jackRtMixCheckBox->setTristate(true);
        backendStackedWidget->addWidget(page_7);
        page_3 = new QWidget();
        page_3->setObjectName(QStringLiteral("page_3"));
        label_17 = new QLabel(page_3);
        label_17->setObjectName(QStringLiteral("label_17"));
        label_17->setGeometry(QRect(10, 30, 141, 21));
        label_17->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        alsaDefaultDeviceLine = new QLineEdit(page_3);
        alsaDefaultDeviceLine->setObjectName(QStringLiteral("alsaDefaultDeviceLine"));
        alsaDefaultDeviceLine->setGeometry(QRect(160, 30, 231, 21));
        label_18 = new QLabel(page_3);
        label_18->setObjectName(QStringLiteral("label_18"));
        label_18->setGeometry(QRect(10, 60, 141, 21));
        label_18->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        alsaDefaultCaptureLine = new QLineEdit(page_3);
        alsaDefaultCaptureLine->setObjectName(QStringLiteral("alsaDefaultCaptureLine"));
        alsaDefaultCaptureLine->setGeometry(QRect(160, 60, 231, 21));
        alsaResamplerCheckBox = new QCheckBox(page_3);
        alsaResamplerCheckBox->setObjectName(QStringLiteral("alsaResamplerCheckBox"));
        alsaResamplerCheckBox->setGeometry(QRect(20, 100, 191, 21));
        alsaResamplerCheckBox->setTristate(true);
        alsaMmapCheckBox = new QCheckBox(page_3);
        alsaMmapCheckBox->setObjectName(QStringLiteral("alsaMmapCheckBox"));
        alsaMmapCheckBox->setGeometry(QRect(210, 100, 191, 21));
        alsaMmapCheckBox->setTristate(true);
        backendStackedWidget->addWidget(page_3);
        page_4 = new QWidget();
        page_4->setObjectName(QStringLiteral("page_4"));
        label_20 = new QLabel(page_4);
        label_20->setObjectName(QStringLiteral("label_20"));
        label_20->setGeometry(QRect(10, 30, 141, 21));
        label_20->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        ossDefaultDeviceLine = new QLineEdit(page_4);
        ossDefaultDeviceLine->setObjectName(QStringLiteral("ossDefaultDeviceLine"));
        ossDefaultDeviceLine->setGeometry(QRect(160, 30, 151, 21));
        label_21 = new QLabel(page_4);
        label_21->setObjectName(QStringLiteral("label_21"));
        label_21->setGeometry(QRect(10, 60, 141, 21));
        label_21->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        ossDefaultCaptureLine = new QLineEdit(page_4);
        ossDefaultCaptureLine->setObjectName(QStringLiteral("ossDefaultCaptureLine"));
        ossDefaultCaptureLine->setGeometry(QRect(160, 60, 151, 21));
        ossPlaybackPushButton = new QPushButton(page_4);
        ossPlaybackPushButton->setObjectName(QStringLiteral("ossPlaybackPushButton"));
        ossPlaybackPushButton->setGeometry(QRect(320, 30, 91, 21));
        ossCapturePushButton = new QPushButton(page_4);
        ossCapturePushButton->setObjectName(QStringLiteral("ossCapturePushButton"));
        ossCapturePushButton->setGeometry(QRect(320, 60, 91, 21));
        backendStackedWidget->addWidget(page_4);
        page_5 = new QWidget();
        page_5->setObjectName(QStringLiteral("page_5"));
        solarisDefaultDeviceLine = new QLineEdit(page_5);
        solarisDefaultDeviceLine->setObjectName(QStringLiteral("solarisDefaultDeviceLine"));
        solarisDefaultDeviceLine->setGeometry(QRect(160, 30, 151, 21));
        label_22 = new QLabel(page_5);
        label_22->setObjectName(QStringLiteral("label_22"));
        label_22->setGeometry(QRect(10, 30, 141, 21));
        label_22->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        solarisPlaybackPushButton = new QPushButton(page_5);
        solarisPlaybackPushButton->setObjectName(QStringLiteral("solarisPlaybackPushButton"));
        solarisPlaybackPushButton->setGeometry(QRect(320, 30, 91, 21));
        backendStackedWidget->addWidget(page_5);
        page_6 = new QWidget();
        page_6->setObjectName(QStringLiteral("page_6"));
        label_23 = new QLabel(page_6);
        label_23->setObjectName(QStringLiteral("label_23"));
        label_23->setGeometry(QRect(10, 30, 71, 21));
        label_23->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        waveOutputLine = new QLineEdit(page_6);
        waveOutputLine->setObjectName(QStringLiteral("waveOutputLine"));
        waveOutputLine->setGeometry(QRect(90, 30, 221, 21));
        label_24 = new QLabel(page_6);
        label_24->setObjectName(QStringLiteral("label_24"));
        label_24->setGeometry(QRect(0, 90, 421, 71));
        waveOutputButton = new QPushButton(page_6);
        waveOutputButton->setObjectName(QStringLiteral("waveOutputButton"));
        waveOutputButton->setGeometry(QRect(320, 30, 91, 21));
        waveBFormatCheckBox = new QCheckBox(page_6);
        waveBFormatCheckBox->setObjectName(QStringLiteral("waveBFormatCheckBox"));
        waveBFormatCheckBox->setGeometry(QRect(120, 60, 191, 21));
        backendStackedWidget->addWidget(page_6);
        tabWidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName(QStringLiteral("tab_2"));
        srcCountLineEdit = new QLineEdit(tab_2);
        srcCountLineEdit->setObjectName(QStringLiteral("srcCountLineEdit"));
        srcCountLineEdit->setGeometry(QRect(190, 20, 51, 21));
        srcCountLineEdit->setMaxLength(4);
        label_3 = new QLabel(tab_2);
        label_3->setObjectName(QStringLiteral("label_3"));
        label_3->setGeometry(QRect(10, 20, 171, 21));
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_4 = new QLabel(tab_2);
        label_4->setObjectName(QStringLiteral("label_4"));
        label_4->setGeometry(QRect(10, 50, 171, 21));
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        effectSlotLineEdit = new QLineEdit(tab_2);
        effectSlotLineEdit->setObjectName(QStringLiteral("effectSlotLineEdit"));
        effectSlotLineEdit->setGeometry(QRect(190, 50, 51, 21));
        effectSlotLineEdit->setMaxLength(3);
        label_8 = new QLabel(tab_2);
        label_8->setObjectName(QStringLiteral("label_8"));
        label_8->setGeometry(QRect(10, 80, 171, 21));
        label_8->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        srcSendLineEdit = new QLineEdit(tab_2);
        srcSendLineEdit->setObjectName(QStringLiteral("srcSendLineEdit"));
        srcSendLineEdit->setGeometry(QRect(190, 80, 51, 21));
        srcSendLineEdit->setMaxLength(2);
        cpuExtGroupBox = new QGroupBox(tab_2);
        cpuExtGroupBox->setObjectName(QStringLiteral("cpuExtGroupBox"));
        cpuExtGroupBox->setGeometry(QRect(10, 120, 511, 121));
        enableSSECheckBox = new QCheckBox(cpuExtGroupBox);
        enableSSECheckBox->setObjectName(QStringLiteral("enableSSECheckBox"));
        enableSSECheckBox->setGeometry(QRect(100, 20, 71, 31));
        enableSSECheckBox->setChecked(true);
        enableSSE2CheckBox = new QCheckBox(cpuExtGroupBox);
        enableSSE2CheckBox->setObjectName(QStringLiteral("enableSSE2CheckBox"));
        enableSSE2CheckBox->setGeometry(QRect(180, 20, 71, 31));
        enableSSE2CheckBox->setChecked(true);
        enableNeonCheckBox = new QCheckBox(cpuExtGroupBox);
        enableNeonCheckBox->setObjectName(QStringLiteral("enableNeonCheckBox"));
        enableNeonCheckBox->setGeometry(QRect(100, 50, 71, 31));
        enableNeonCheckBox->setChecked(true);
        enableSSE41CheckBox = new QCheckBox(cpuExtGroupBox);
        enableSSE41CheckBox->setObjectName(QStringLiteral("enableSSE41CheckBox"));
        enableSSE41CheckBox->setGeometry(QRect(340, 20, 71, 31));
        enableSSE41CheckBox->setChecked(true);
        enableSSE3CheckBox = new QCheckBox(cpuExtGroupBox);
        enableSSE3CheckBox->setObjectName(QStringLiteral("enableSSE3CheckBox"));
        enableSSE3CheckBox->setGeometry(QRect(260, 20, 71, 31));
        enableSSE3CheckBox->setChecked(true);
        cpuExtDisabledLabel = new QLabel(cpuExtGroupBox);
        cpuExtDisabledLabel->setObjectName(QStringLiteral("cpuExtDisabledLabel"));
        cpuExtDisabledLabel->setGeometry(QRect(101, 80, 311, 31));
        tabWidget->addTab(tab_2, QString());
        tab_4 = new QWidget();
        tab_4->setObjectName(QStringLiteral("tab_4"));
        groupBox_5 = new QGroupBox(tab_4);
        groupBox_5->setObjectName(QStringLiteral("groupBox_5"));
        groupBox_5->setGeometry(QRect(10, 60, 511, 241));
        enableEaxReverbCheck = new QCheckBox(groupBox_5);
        enableEaxReverbCheck->setObjectName(QStringLiteral("enableEaxReverbCheck"));
        enableEaxReverbCheck->setGeometry(QRect(70, 30, 131, 21));
        enableEaxReverbCheck->setChecked(true);
        enableStdReverbCheck = new QCheckBox(groupBox_5);
        enableStdReverbCheck->setObjectName(QStringLiteral("enableStdReverbCheck"));
        enableStdReverbCheck->setGeometry(QRect(70, 60, 131, 21));
        enableStdReverbCheck->setChecked(true);
        enableChorusCheck = new QCheckBox(groupBox_5);
        enableChorusCheck->setObjectName(QStringLiteral("enableChorusCheck"));
        enableChorusCheck->setGeometry(QRect(70, 90, 131, 21));
        enableChorusCheck->setChecked(true);
        enableDistortionCheck = new QCheckBox(groupBox_5);
        enableDistortionCheck->setObjectName(QStringLiteral("enableDistortionCheck"));
        enableDistortionCheck->setGeometry(QRect(70, 150, 131, 21));
        enableDistortionCheck->setChecked(true);
        enableEchoCheck = new QCheckBox(groupBox_5);
        enableEchoCheck->setObjectName(QStringLiteral("enableEchoCheck"));
        enableEchoCheck->setGeometry(QRect(70, 180, 131, 21));
        enableEchoCheck->setChecked(true);
        enableEqualizerCheck = new QCheckBox(groupBox_5);
        enableEqualizerCheck->setObjectName(QStringLiteral("enableEqualizerCheck"));
        enableEqualizerCheck->setGeometry(QRect(320, 30, 131, 21));
        enableEqualizerCheck->setChecked(true);
        enableFlangerCheck = new QCheckBox(groupBox_5);
        enableFlangerCheck->setObjectName(QStringLiteral("enableFlangerCheck"));
        enableFlangerCheck->setGeometry(QRect(320, 90, 131, 21));
        enableFlangerCheck->setChecked(true);
        enableModulatorCheck = new QCheckBox(groupBox_5);
        enableModulatorCheck->setObjectName(QStringLiteral("enableModulatorCheck"));
        enableModulatorCheck->setGeometry(QRect(320, 150, 131, 21));
        enableModulatorCheck->setChecked(true);
        enableDedicatedCheck = new QCheckBox(groupBox_5);
        enableDedicatedCheck->setObjectName(QStringLiteral("enableDedicatedCheck"));
        enableDedicatedCheck->setGeometry(QRect(320, 180, 131, 21));
        enableDedicatedCheck->setChecked(true);
        enableCompressorCheck = new QCheckBox(groupBox_5);
        enableCompressorCheck->setObjectName(QStringLiteral("enableCompressorCheck"));
        enableCompressorCheck->setGeometry(QRect(70, 120, 111, 21));
        enableCompressorCheck->setChecked(true);
        enablePitchShifterCheck = new QCheckBox(groupBox_5);
        enablePitchShifterCheck->setObjectName(QStringLiteral("enablePitchShifterCheck"));
        enablePitchShifterCheck->setGeometry(QRect(320, 120, 131, 21));
        enablePitchShifterCheck->setChecked(true);
        enableFrequencyShifterCheck = new QCheckBox(groupBox_5);
        enableFrequencyShifterCheck->setObjectName(QStringLiteral("enableFrequencyShifterCheck"));
        enableFrequencyShifterCheck->setGeometry(QRect(320, 60, 131, 21));
        enableFrequencyShifterCheck->setChecked(true);
        enableAutowahCheck = new QCheckBox(groupBox_5);
        enableAutowahCheck->setObjectName(QStringLiteral("enableAutowahCheck"));
        enableAutowahCheck->setGeometry(QRect(70, 210, 131, 21));
        enableAutowahCheck->setChecked(true);
        enableVocalMorpherCheck = new QCheckBox(groupBox_5);
        enableVocalMorpherCheck->setObjectName(QStringLiteral("enableVocalMorpherCheck"));
        enableVocalMorpherCheck->setGeometry(QRect(320, 210, 131, 21));
        enableVocalMorpherCheck->setChecked(true);
        label_13 = new QLabel(tab_4);
        label_13->setObjectName(QStringLiteral("label_13"));
        label_13->setGeometry(QRect(10, 20, 141, 31));
        label_13->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        defaultReverbComboBox = new QComboBox(tab_4);
        defaultReverbComboBox->setObjectName(QStringLiteral("defaultReverbComboBox"));
        defaultReverbComboBox->setGeometry(QRect(160, 20, 135, 31));
        defaultReverbComboBox->setSizeAdjustPolicy(QComboBox::AdjustToContents);
        enableEaxCheck = new QCheckBox(tab_4);
        enableEaxCheck->setObjectName(QStringLiteral("enableEaxCheck"));
        enableEaxCheck->setGeometry(QRect(30, 320, 231, 21));
        tabWidget->addTab(tab_4, QString());
        closeCancelButton = new QPushButton(centralWidget);
        closeCancelButton->setObjectName(QStringLiteral("closeCancelButton"));
        closeCancelButton->setGeometry(QRect(370, 405, 91, 31));
        QIcon icon7;
        iconThemeName = QStringLiteral("window-close");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon7 = QIcon::fromTheme(iconThemeName);
        } else {
            icon7.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        closeCancelButton->setIcon(icon7);
        MainWindow->setCentralWidget(centralWidget);
        menuBar = new QMenuBar(MainWindow);
        menuBar->setObjectName(QStringLiteral("menuBar"));
        menuBar->setGeometry(QRect(0, 0, 564, 29));
        menuFile = new QMenu(menuBar);
        menuFile->setObjectName(QStringLiteral("menuFile"));
        menuHelp = new QMenu(menuBar);
        menuHelp->setObjectName(QStringLiteral("menuHelp"));
        MainWindow->setMenuBar(menuBar);

        menuBar->addAction(menuFile->menuAction());
        menuBar->addAction(menuHelp->menuAction());
        menuFile->addAction(actionLoad);
        menuFile->addAction(actionSave_As);
        menuFile->addSeparator();
        menuFile->addAction(actionQuit);
        menuHelp->addAction(actionAbout);

        retranslateUi(MainWindow);
        QObject::connect(backendListWidget, SIGNAL(currentRowChanged(int)), backendStackedWidget, SLOT(setCurrentIndex(int)));

        tabWidget->setCurrentIndex(0);
        backendStackedWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(MainWindow);
    } // setupUi

    void retranslateUi(QMainWindow *MainWindow)
    {
        MainWindow->setWindowTitle(QApplication::translate("MainWindow", "OpenAL Soft Configuration", Q_NULLPTR));
        actionQuit->setText(QApplication::translate("MainWindow", "&Quit", Q_NULLPTR));
        actionSave_As->setText(QApplication::translate("MainWindow", "Save &As...", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        actionSave_As->setToolTip(QApplication::translate("MainWindow", "Save Configuration As", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        actionLoad->setText(QApplication::translate("MainWindow", "&Load...", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        actionLoad->setToolTip(QApplication::translate("MainWindow", "Load Configuration File", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        actionAbout->setText(QApplication::translate("MainWindow", "&About...", Q_NULLPTR));
        applyButton->setText(QApplication::translate("MainWindow", "Apply", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        sampleFormatCombo->setToolTip(QApplication::translate("MainWindow", "The output sample type. Currently, all mixing is done with 32-bit\n"
"float and converted to the output sample type as needed.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        label_5->setText(QApplication::translate("MainWindow", "Sample Format:", Q_NULLPTR));
        label_6->setText(QApplication::translate("MainWindow", "Channels:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        channelConfigCombo->setToolTip(QApplication::translate("MainWindow", "The default output channel configuration. Note that not all\n"
"backends can properly detect the channel configuration and\n"
"may default to stereo output.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        sampleRateCombo->clear();
        sampleRateCombo->insertItems(0, QStringList()
         << QApplication::translate("MainWindow", "Autodetect", Q_NULLPTR)
         << QApplication::translate("MainWindow", "8000", Q_NULLPTR)
         << QApplication::translate("MainWindow", "11025", Q_NULLPTR)
         << QApplication::translate("MainWindow", "16000", Q_NULLPTR)
         << QApplication::translate("MainWindow", "22050", Q_NULLPTR)
         << QApplication::translate("MainWindow", "32000", Q_NULLPTR)
         << QApplication::translate("MainWindow", "44100", Q_NULLPTR)
         << QApplication::translate("MainWindow", "48000", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        sampleRateCombo->setToolTip(QApplication::translate("MainWindow", "The playback/mixing sample rate.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        label_7->setText(QApplication::translate("MainWindow", "Sample Rate:", Q_NULLPTR));
        label_14->setText(QApplication::translate("MainWindow", "Stereo Mode:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        stereoModeCombo->setToolTip(QApplication::translate("MainWindow", "How to treat stereo output. As headphones, HRTF or crossfeed\n"
"filters may be used to improve binaural quality, which may not\n"
"otherwise be suitable for speakers.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        groupBox->setTitle(QApplication::translate("MainWindow", "Advanced Settings", Q_NULLPTR));
        groupBox_3->setTitle(QApplication::translate("MainWindow", "Buffer Metrics", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        widget->setToolTip(QApplication::translate("MainWindow", "The number of update periods. Higher values create a larger\n"
"mix ahead, which helps protect against skips when the CPU is\n"
"under load, but increases the delay between a sound getting\n"
"mixed and being heard.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        label_11->setText(QApplication::translate("MainWindow", "Period Count", Q_NULLPTR));
        periodCountEdit->setPlaceholderText(QApplication::translate("MainWindow", "3", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        widget_2->setToolTip(QApplication::translate("MainWindow", "The update period size, in sample frames. This is the number of\n"
"frames needed for each mixing update.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        label_10->setText(QApplication::translate("MainWindow", "Period Samples", Q_NULLPTR));
        periodSizeEdit->setPlaceholderText(QApplication::translate("MainWindow", "20ms", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        stereoEncodingComboBox->setToolTip(QApplication::translate("MainWindow", "Basic uses standard amplitude panning (aka\n"
"pair-wise, stereo pair, etc).\n"
"\n"
"UHJ creates a stereo-compatible two-channel\n"
"UHJ mix, which encodes some surround sound\n"
"information into stereo output that can be\n"
"decoded with a surround sound receiver.\n"
"\n"
"Binaural applies HRTF filters to create an\n"
"illusion of 3D placement with headphones.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        label_19->setText(QApplication::translate("MainWindow", "Stereo Encoding:", Q_NULLPTR));
        label_30->setText(QApplication::translate("MainWindow", "Ambisonic Format:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        outputLimiterCheckBox->setToolTip(QApplication::translate("MainWindow", "Applies a gain limiter on the final mixed output. This reduces the\n"
"volume when the output samples would otherwise be clamped,\n"
"avoiding excessive clipping noise.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        outputLimiterCheckBox->setText(QApplication::translate("MainWindow", "Enable Gain Limiter", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        outputDitherCheckBox->setToolTip(QApplication::translate("MainWindow", "Applies dithering on the final mix for 8- and 16-bit output.\n"
"This replaces the distortion created by nearest-value\n"
"quantization with low-level whitenoise.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        outputDitherCheckBox->setText(QApplication::translate("MainWindow", "Enable Dithering", Q_NULLPTR));
        groupBox_4->setTitle(QApplication::translate("MainWindow", "Resampler Quality", Q_NULLPTR));
        resamplerLabel->setText(QApplication::translate("MainWindow", "Default", Q_NULLPTR));
        label_9->setText(QApplication::translate("MainWindow", "Speed", Q_NULLPTR));
        label_15->setText(QApplication::translate("MainWindow", "Quality", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(tab_3), QApplication::translate("MainWindow", "Playback", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        decoderHQModeCheckBox->setToolTip(QApplication::translate("MainWindow", "Enables high-quality ambisonic rendering. This mode is\n"
"capable of frequency-dependent processing, creating a\n"
"better reproduction of 3D sound rendering over\n"
"surround sound speakers.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        decoderHQModeCheckBox->setText(QApplication::translate("MainWindow", "High Quality Mode:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        decoderDistCompCheckBox->setToolTip(QApplication::translate("MainWindow", "This applies the necessary delays and attenuation\n"
"to make the speakers behave as though they are\n"
"all equidistant, which is important for proper\n"
"playback of 3D sound rendering. Requires the\n"
"proper distances to be specified in the decoder\n"
"configuration file.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        decoderDistCompCheckBox->setText(QApplication::translate("MainWindow", "Distance Compensation:", Q_NULLPTR));
        groupBox_8->setTitle(QApplication::translate("MainWindow", "Decoder Configurations", Q_NULLPTR));
        label_25->setText(QApplication::translate("MainWindow", "Quadraphonic:", Q_NULLPTR));
        decoderQuadButton->setText(QApplication::translate("MainWindow", "Browse...", Q_NULLPTR));
        decoder51Button->setText(QApplication::translate("MainWindow", "Browse...", Q_NULLPTR));
        label_26->setText(QApplication::translate("MainWindow", "5.1 Surround:", Q_NULLPTR));
        label_28->setText(QApplication::translate("MainWindow", "6.1 Surround:", Q_NULLPTR));
        decoder61Button->setText(QApplication::translate("MainWindow", "Browse...", Q_NULLPTR));
        decoder71Button->setText(QApplication::translate("MainWindow", "Browse...", Q_NULLPTR));
        label_29->setText(QApplication::translate("MainWindow", "7.1 Surround:", Q_NULLPTR));
        label_33->setText(QApplication::translate("MainWindow", "3D7.1 Surround:", Q_NULLPTR));
        decoder3D71Button->setText(QApplication::translate("MainWindow", "Browse...", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        decoderNFEffectsCheckBox->setToolTip(QApplication::translate("MainWindow", "Simulates and compensates for low-frequency effects\n"
"caused by the curvature of nearby sound-waves, which\n"
"creates a more realistic perception of sound distance.\n"
"Note that the effect may be stronger or weaker than\n"
"intended if the application doesn't use or specify an\n"
"appropriate unit scale, or if incorrect speaker distances\n"
"are set in the decoder configuration file.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        decoderNFEffectsCheckBox->setText(QApplication::translate("MainWindow", "Near-Field Effects:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        widget_3->setToolTip(QApplication::translate("MainWindow", "Specifies the speaker distance in meters, used by the near-field control\n"
"filters with surround sound output. For ambisonic output modes, this value\n"
"is the basis for the NFC-HOA Reference Delay parameter (calculated as\n"
"delay_seconds = speaker_dist/343.3). This value is not used when a decoder\n"
"configuration is set for the output mode (since they specify the per-speaker\n"
"distances, overriding this setting), or when the NFC filters are off.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        label_27->setText(QApplication::translate("MainWindow", "Speaker Distance:", Q_NULLPTR));
        decoderSpeakerDistSpinBox->setSuffix(QApplication::translate("MainWindow", " meters", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(tab_6), QApplication::translate("MainWindow", "Renderer", Q_NULLPTR));
        groupBox_2->setTitle(QApplication::translate("MainWindow", "Advanced Settings", Q_NULLPTR));
        groupBox_6->setTitle(QApplication::translate("MainWindow", "HRTF Profile Paths", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        hrtfFileList->setToolTip(QApplication::translate("MainWindow", "A list of additional paths containing HRTF data sets.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        hrtfAddButton->setText(QApplication::translate("MainWindow", "Add...", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        defaultHrtfPathsCheckBox->setToolTip(QApplication::translate("MainWindow", "Include the default system paths in addition to any\n"
"listed above.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        defaultHrtfPathsCheckBox->setText(QApplication::translate("MainWindow", "Include Default Paths", Q_NULLPTR));
        hrtfRemoveButton->setText(QApplication::translate("MainWindow", "Remove", Q_NULLPTR));
        label_12->setText(QApplication::translate("MainWindow", "Preferred HRTF:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        preferredHrtfComboBox->setToolTip(QApplication::translate("MainWindow", "The default HRTF to use if the application doesn't request one.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        groupBox_9->setTitle(QApplication::translate("MainWindow", "HRTF Render Method", Q_NULLPTR));
        label_31->setText(QApplication::translate("MainWindow", "Speed", Q_NULLPTR));
        label_32->setText(QApplication::translate("MainWindow", "Quality", Q_NULLPTR));
        hrtfmodeLabel->setText(QApplication::translate("MainWindow", "Default", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(tab_5), QApplication::translate("MainWindow", "HRTF", Q_NULLPTR));

        const bool __sortingEnabled = backendListWidget->isSortingEnabled();
        backendListWidget->setSortingEnabled(false);
        QListWidgetItem *___qlistwidgetitem = backendListWidget->item(0);
        ___qlistwidgetitem->setText(QApplication::translate("MainWindow", "General", Q_NULLPTR));
        QListWidgetItem *___qlistwidgetitem1 = backendListWidget->item(1);
        ___qlistwidgetitem1->setText(QApplication::translate("MainWindow", "PipeWire", Q_NULLPTR));
        QListWidgetItem *___qlistwidgetitem2 = backendListWidget->item(2);
        ___qlistwidgetitem2->setText(QApplication::translate("MainWindow", "WASAPI", Q_NULLPTR));
        QListWidgetItem *___qlistwidgetitem3 = backendListWidget->item(3);
        ___qlistwidgetitem3->setText(QApplication::translate("MainWindow", "PulseAudio", Q_NULLPTR));
        QListWidgetItem *___qlistwidgetitem4 = backendListWidget->item(4);
        ___qlistwidgetitem4->setText(QApplication::translate("MainWindow", "JACK", Q_NULLPTR));
        QListWidgetItem *___qlistwidgetitem5 = backendListWidget->item(5);
        ___qlistwidgetitem5->setText(QApplication::translate("MainWindow", "ALSA", Q_NULLPTR));
        QListWidgetItem *___qlistwidgetitem6 = backendListWidget->item(6);
        ___qlistwidgetitem6->setText(QApplication::translate("MainWindow", "OSS", Q_NULLPTR));
        QListWidgetItem *___qlistwidgetitem7 = backendListWidget->item(7);
        ___qlistwidgetitem7->setText(QApplication::translate("MainWindow", "Solaris", Q_NULLPTR));
        QListWidgetItem *___qlistwidgetitem8 = backendListWidget->item(8);
        ___qlistwidgetitem8->setText(QApplication::translate("MainWindow", "Wave Writer", Q_NULLPTR));
        backendListWidget->setSortingEnabled(__sortingEnabled);

#ifndef QT_NO_TOOLTIP
        backendCheckBox->setToolTip(QApplication::translate("MainWindow", "When checked, allows all other available backends not listed in the priority or disabled lists.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        backendCheckBox->setText(QApplication::translate("MainWindow", "Allow Other Backends", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        disabledBackendList->setToolTip(QApplication::translate("MainWindow", "Disabled backend driver list.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        enabledBackendList->setToolTip(QApplication::translate("MainWindow", "The backend driver list order. Unknown backends and\n"
"duplicated names are ignored.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        label_2->setText(QApplication::translate("MainWindow", "Disabled Backends:", Q_NULLPTR));
        label->setText(QApplication::translate("MainWindow", "Priority Backends:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        pwireAssumeAudioCheckBox->setToolTip(QApplication::translate("MainWindow", "Assumes PipeWire has support for audio, allowing\n"
"the backend to initialize even when no audio devices\n"
"are reported.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pwireAssumeAudioCheckBox->setText(QApplication::translate("MainWindow", "Assume audio support", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        pwireRtMixCheckBox->setToolTip(QApplication::translate("MainWindow", "Renders samples directly in the real-time\n"
"processing callback. This allows for lower\n"
"latency and less overall CPU utilization, but\n"
"can increase the risk of underruns when\n"
"increasing the amount of processing the\n"
"mixer needs to do.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pwireRtMixCheckBox->setText(QApplication::translate("MainWindow", "Real-time Mixing", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        wasapiResamplerCheckBox->setToolTip(QApplication::translate("MainWindow", "Specifies whether to allow an extra resampler pass on the output. Enabling\n"
"this will allow the playback device to be set to a different sample rate\n"
"than the actual output can accept, causing the backend to apply its own\n"
"resampling pass after OpenAL Soft mixes the sources and processes effects\n"
"for output.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        wasapiResamplerCheckBox->setText(QApplication::translate("MainWindow", "Allow Resampler", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        pulseAutospawnCheckBox->setToolTip(QApplication::translate("MainWindow", "Automatically spawn a PulseAudio server if one\n"
"is not already running.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pulseAutospawnCheckBox->setText(QApplication::translate("MainWindow", "AutoSpawn Server", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        pulseAllowMovesCheckBox->setToolTip(QApplication::translate("MainWindow", "Allows moving PulseAudio streams to different\n"
"devices during playback or capture. Note that the\n"
"device specifier and device format will not change\n"
"to match the new device.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pulseAllowMovesCheckBox->setText(QApplication::translate("MainWindow", "Allow Moving Streams", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        pulseFixRateCheckBox->setToolTip(QApplication::translate("MainWindow", "When checked, fix the OpenAL device's sample\n"
"rate to match the PulseAudio device.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pulseFixRateCheckBox->setText(QApplication::translate("MainWindow", "Fix Sample Rate", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        pulseAdjLatencyCheckBox->setToolTip(QApplication::translate("MainWindow", "Attempts to adjust the overall latency of device\n"
"playback. Note that this may have adverse effects\n"
"on the resulting internal buffer sizes and mixing\n"
"updates, leading to performance problems and\n"
"drop-outs.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pulseAdjLatencyCheckBox->setText(QApplication::translate("MainWindow", "Adjust Latency", Q_NULLPTR));
        jackAutospawnCheckBox->setText(QApplication::translate("MainWindow", "AutoSpawn Server", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        groupBox_7->setToolTip(QApplication::translate("MainWindow", "The update buffer size, in samples, that the backend\n"
"will keep buffered to handle the server's real-time\n"
"processing requests. Must be a power of 2. Ignored\n"
"when Real-time Mixing is used.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        groupBox_7->setTitle(QApplication::translate("MainWindow", "Buffer Size", Q_NULLPTR));
        jackBufferSizeLine->setPlaceholderText(QApplication::translate("MainWindow", "0", Q_NULLPTR));
        jackConnectPortsCheckBox->setText(QApplication::translate("MainWindow", "AutoConnect Ports", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        jackRtMixCheckBox->setToolTip(QApplication::translate("MainWindow", "Renders samples directly in the real-time\n"
"processing callback. This allows for lower\n"
"latency and less overall CPU utilization, but\n"
"can increase the risk of underruns when\n"
"increasing the amount of processing the\n"
"mixer needs to do.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        jackRtMixCheckBox->setText(QApplication::translate("MainWindow", "Real-time Mixing", Q_NULLPTR));
        label_17->setText(QApplication::translate("MainWindow", "Default Playback Device:", Q_NULLPTR));
        alsaDefaultDeviceLine->setPlaceholderText(QApplication::translate("MainWindow", "default", Q_NULLPTR));
        label_18->setText(QApplication::translate("MainWindow", "Default Capture Device:", Q_NULLPTR));
        alsaDefaultCaptureLine->setPlaceholderText(QApplication::translate("MainWindow", "default", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        alsaResamplerCheckBox->setToolTip(QApplication::translate("MainWindow", "Allow use of ALSA's software resampler. This lets\n"
"the OpenAL device to be set to a different sample\n"
"rate than the backend device, but incurs another\n"
"resample pass on top of OpenAL's resampler.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        alsaResamplerCheckBox->setText(QApplication::translate("MainWindow", "Allow Resampler", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        alsaMmapCheckBox->setToolTip(QApplication::translate("MainWindow", "Accesses the audio device buffer through an mmap,\n"
"potentially avoiding an extra sample buffer copy\n"
"during updates.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        alsaMmapCheckBox->setText(QApplication::translate("MainWindow", "MMap Buffer", Q_NULLPTR));
        label_20->setText(QApplication::translate("MainWindow", "Default Playback Device:", Q_NULLPTR));
        ossDefaultDeviceLine->setPlaceholderText(QApplication::translate("MainWindow", "/dev/dsp", Q_NULLPTR));
        label_21->setText(QApplication::translate("MainWindow", "Default Capture Device:", Q_NULLPTR));
        ossDefaultCaptureLine->setPlaceholderText(QApplication::translate("MainWindow", "/dev/dsp", Q_NULLPTR));
        ossPlaybackPushButton->setText(QApplication::translate("MainWindow", "Browse...", Q_NULLPTR));
        ossCapturePushButton->setText(QApplication::translate("MainWindow", "Browse...", Q_NULLPTR));
        solarisDefaultDeviceLine->setPlaceholderText(QApplication::translate("MainWindow", "/dev/audio", Q_NULLPTR));
        label_22->setText(QApplication::translate("MainWindow", "Default Playback Device:", Q_NULLPTR));
        solarisPlaybackPushButton->setText(QApplication::translate("MainWindow", "Browse...", Q_NULLPTR));
        label_23->setText(QApplication::translate("MainWindow", "Output File:", Q_NULLPTR));
        label_24->setText(QApplication::translate("MainWindow", "<html><head/><body><p align=\"center\"><span style=\" font-style:italic;\">Warning: The specified output file will be OVERWRITTEN WITHOUT</span></p><p align=\"center\"><span style=\" font-style:italic;\">QUESTION when the Wave Writer device is opened.</span></p></body></html>", Q_NULLPTR));
        waveOutputButton->setText(QApplication::translate("MainWindow", "Browse...", Q_NULLPTR));
        waveBFormatCheckBox->setText(QApplication::translate("MainWindow", "Create .amb (B-Format) files", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(tab), QApplication::translate("MainWindow", "Backends", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        srcCountLineEdit->setToolTip(QApplication::translate("MainWindow", "The maximum number of allocatable sources. Lower values may\n"
"help for systems with apps that try to play more sounds than\n"
"the CPU can handle.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        srcCountLineEdit->setPlaceholderText(QApplication::translate("MainWindow", "256", Q_NULLPTR));
        label_3->setText(QApplication::translate("MainWindow", "Number of Sound Sources:", Q_NULLPTR));
        label_4->setText(QApplication::translate("MainWindow", "Number of Effect Slots:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        effectSlotLineEdit->setToolTip(QApplication::translate("MainWindow", "The maximum number of Auxiliary Effect Slots an app can\n"
"create. A slot can use a non-negligible amount of CPU time if\n"
"an effect is set on it even if no sources are feeding it, so this\n"
"may help when apps use more than the system can handle.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        effectSlotLineEdit->setPlaceholderText(QApplication::translate("MainWindow", "64", Q_NULLPTR));
        label_8->setText(QApplication::translate("MainWindow", "Number of Source Sends:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        srcSendLineEdit->setToolTip(QApplication::translate("MainWindow", "Limits the number of auxiliary sends allowed per source.\n"
"Setting this higher than the default has no effect.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        srcSendLineEdit->setPlaceholderText(QApplication::translate("MainWindow", "16", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        cpuExtGroupBox->setToolTip(QApplication::translate("MainWindow", "Enables use of specific CPU extensions. Certain methods may\n"
"utilize CPU extensions when detected, and disabling these can\n"
"be useful for preventing those extensions from being used.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        cpuExtGroupBox->setTitle(QApplication::translate("MainWindow", "CPU Extensions", Q_NULLPTR));
        enableSSECheckBox->setText(QApplication::translate("MainWindow", "SSE", Q_NULLPTR));
        enableSSE2CheckBox->setText(QApplication::translate("MainWindow", "SSE2", Q_NULLPTR));
        enableNeonCheckBox->setText(QApplication::translate("MainWindow", "Neon", Q_NULLPTR));
        enableSSE41CheckBox->setText(QApplication::translate("MainWindow", "SSE4.1", Q_NULLPTR));
        enableSSE3CheckBox->setText(QApplication::translate("MainWindow", "SSE3", Q_NULLPTR));
        cpuExtDisabledLabel->setText(QApplication::translate("MainWindow", "<html><head/><body><p align=\"center\"><span style=\" font-style:italic;\">No support enabled for CPU Extensions</span></p></body></html>", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), QApplication::translate("MainWindow", "Resources", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        groupBox_5->setToolTip(QApplication::translate("MainWindow", "Specifies which effects apps can recognize. Disabling effects\n"
"can help for apps that try to use ones that are too intensive\n"
"for the system to handle.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        groupBox_5->setTitle(QApplication::translate("MainWindow", "Enabled Effects", Q_NULLPTR));
        enableEaxReverbCheck->setText(QApplication::translate("MainWindow", "EAX Reverb", Q_NULLPTR));
        enableStdReverbCheck->setText(QApplication::translate("MainWindow", "Standard Reverb", Q_NULLPTR));
        enableChorusCheck->setText(QApplication::translate("MainWindow", "Chorus", Q_NULLPTR));
        enableDistortionCheck->setText(QApplication::translate("MainWindow", "Distortion", Q_NULLPTR));
        enableEchoCheck->setText(QApplication::translate("MainWindow", "Echo", Q_NULLPTR));
        enableEqualizerCheck->setText(QApplication::translate("MainWindow", "Equalizer", Q_NULLPTR));
        enableFlangerCheck->setText(QApplication::translate("MainWindow", "Flanger", Q_NULLPTR));
        enableModulatorCheck->setText(QApplication::translate("MainWindow", "Ring Modulator", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        enableDedicatedCheck->setToolTip(QApplication::translate("MainWindow", "Enables both the Dedicated Dialog and Dedicated LFE effects\n"
"added by the ALC_EXT_DEDICATED extension.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        enableDedicatedCheck->setText(QApplication::translate("MainWindow", "Dedicated ...", Q_NULLPTR));
        enableCompressorCheck->setText(QApplication::translate("MainWindow", "Compressor", Q_NULLPTR));
        enablePitchShifterCheck->setText(QApplication::translate("MainWindow", "Pitch Shifter", Q_NULLPTR));
        enableFrequencyShifterCheck->setText(QApplication::translate("MainWindow", "Frequency Shifter", Q_NULLPTR));
        enableAutowahCheck->setText(QApplication::translate("MainWindow", "Autowah", Q_NULLPTR));
        enableVocalMorpherCheck->setText(QApplication::translate("MainWindow", "Vocal morpher", Q_NULLPTR));
        label_13->setText(QApplication::translate("MainWindow", "Default Reverb Effect:", Q_NULLPTR));
        defaultReverbComboBox->clear();
        defaultReverbComboBox->insertItems(0, QStringList()
         << QApplication::translate("MainWindow", "None", Q_NULLPTR)
         << QApplication::translate("MainWindow", "Generic", Q_NULLPTR)
         << QApplication::translate("MainWindow", "PaddedCell", Q_NULLPTR)
         << QApplication::translate("MainWindow", "Room", Q_NULLPTR)
         << QApplication::translate("MainWindow", "Bathroom", Q_NULLPTR)
         << QApplication::translate("MainWindow", "Livingroom", Q_NULLPTR)
         << QApplication::translate("MainWindow", "Stoneroom", Q_NULLPTR)
         << QApplication::translate("MainWindow", "Auditorium", Q_NULLPTR)
         << QApplication::translate("MainWindow", "ConcertHall", Q_NULLPTR)
         << QApplication::translate("MainWindow", "Cave", Q_NULLPTR)
         << QApplication::translate("MainWindow", "Arena", Q_NULLPTR)
         << QApplication::translate("MainWindow", "Hangar", Q_NULLPTR)
         << QApplication::translate("MainWindow", "CarpetedHallway", Q_NULLPTR)
         << QApplication::translate("MainWindow", "Hallway", Q_NULLPTR)
         << QApplication::translate("MainWindow", "StoneCorridor", Q_NULLPTR)
         << QApplication::translate("MainWindow", "Alley", Q_NULLPTR)
         << QApplication::translate("MainWindow", "Forest", Q_NULLPTR)
         << QApplication::translate("MainWindow", "City", Q_NULLPTR)
         << QApplication::translate("MainWindow", "Mountains", Q_NULLPTR)
         << QApplication::translate("MainWindow", "Quarry", Q_NULLPTR)
         << QApplication::translate("MainWindow", "Plain", Q_NULLPTR)
         << QApplication::translate("MainWindow", "ParkingLot", Q_NULLPTR)
         << QApplication::translate("MainWindow", "SewerPipe", Q_NULLPTR)
         << QApplication::translate("MainWindow", "Underwater", Q_NULLPTR)
         << QApplication::translate("MainWindow", "Drugged", Q_NULLPTR)
         << QApplication::translate("MainWindow", "Dizzy", Q_NULLPTR)
         << QApplication::translate("MainWindow", "Psychotic", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        enableEaxCheck->setToolTip(QApplication::translate("MainWindow", "Enables legacy EAX API support.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        enableEaxCheck->setText(QApplication::translate("MainWindow", "Enable EAX API support", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(tab_4), QApplication::translate("MainWindow", "Effects", Q_NULLPTR));
        closeCancelButton->setText(QApplication::translate("MainWindow", "Cancel", Q_NULLPTR));
        menuFile->setTitle(QApplication::translate("MainWindow", "&File", Q_NULLPTR));
        menuHelp->setTitle(QApplication::translate("MainWindow", "&Help", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class MainWindow: public Ui_MainWindow {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MAINWINDOW_H
