/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/openal-soft-1.24.3/utils/alsoft-config/mainwindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_MainWindow_t {
    QByteArrayData data[34];
    char stringdata0[592];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MainWindow_t qt_meta_stringdata_MainWindow = {
    {
QT_MOC_LITERAL(0, 0, 10), // "MainWindow"
QT_MOC_LITERAL(1, 11, 17), // "cancelCloseAction"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 17), // "saveCurrentConfig"
QT_MOC_LITERAL(4, 48, 16), // "saveConfigAsFile"
QT_MOC_LITERAL(5, 65, 18), // "loadConfigFromFile"
QT_MOC_LITERAL(6, 84, 13), // "showAboutPage"
QT_MOC_LITERAL(7, 98, 17), // "enableApplyButton"
QT_MOC_LITERAL(8, 116, 20), // "updateResamplerLabel"
QT_MOC_LITERAL(9, 137, 3), // "num"
QT_MOC_LITERAL(10, 141, 20), // "updatePeriodSizeEdit"
QT_MOC_LITERAL(11, 162, 4), // "size"
QT_MOC_LITERAL(12, 167, 22), // "updatePeriodSizeSlider"
QT_MOC_LITERAL(13, 190, 21), // "updatePeriodCountEdit"
QT_MOC_LITERAL(14, 212, 5), // "count"
QT_MOC_LITERAL(15, 218, 23), // "updatePeriodCountSlider"
QT_MOC_LITERAL(16, 242, 21), // "selectQuadDecoderFile"
QT_MOC_LITERAL(17, 264, 19), // "select51DecoderFile"
QT_MOC_LITERAL(18, 284, 19), // "select61DecoderFile"
QT_MOC_LITERAL(19, 304, 19), // "select71DecoderFile"
QT_MOC_LITERAL(20, 324, 21), // "select3D71DecoderFile"
QT_MOC_LITERAL(21, 346, 24), // "updateJackBufferSizeEdit"
QT_MOC_LITERAL(22, 371, 26), // "updateJackBufferSizeSlider"
QT_MOC_LITERAL(23, 398, 19), // "updateHrtfModeLabel"
QT_MOC_LITERAL(24, 418, 11), // "addHrtfFile"
QT_MOC_LITERAL(25, 430, 14), // "removeHrtfFile"
QT_MOC_LITERAL(26, 445, 22), // "updateHrtfRemoveButton"
QT_MOC_LITERAL(27, 468, 22), // "showEnabledBackendMenu"
QT_MOC_LITERAL(28, 491, 2), // "pt"
QT_MOC_LITERAL(29, 494, 23), // "showDisabledBackendMenu"
QT_MOC_LITERAL(30, 518, 17), // "selectOSSPlayback"
QT_MOC_LITERAL(31, 536, 16), // "selectOSSCapture"
QT_MOC_LITERAL(32, 553, 21), // "selectSolarisPlayback"
QT_MOC_LITERAL(33, 575, 16) // "selectWaveOutput"

    },
    "MainWindow\0cancelCloseAction\0\0"
    "saveCurrentConfig\0saveConfigAsFile\0"
    "loadConfigFromFile\0showAboutPage\0"
    "enableApplyButton\0updateResamplerLabel\0"
    "num\0updatePeriodSizeEdit\0size\0"
    "updatePeriodSizeSlider\0updatePeriodCountEdit\0"
    "count\0updatePeriodCountSlider\0"
    "selectQuadDecoderFile\0select51DecoderFile\0"
    "select61DecoderFile\0select71DecoderFile\0"
    "select3D71DecoderFile\0updateJackBufferSizeEdit\0"
    "updateJackBufferSizeSlider\0"
    "updateHrtfModeLabel\0addHrtfFile\0"
    "removeHrtfFile\0updateHrtfRemoveButton\0"
    "showEnabledBackendMenu\0pt\0"
    "showDisabledBackendMenu\0selectOSSPlayback\0"
    "selectOSSCapture\0selectSolarisPlayback\0"
    "selectWaveOutput"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MainWindow[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      28,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  154,    2, 0x08 /* Private */,
       3,    0,  155,    2, 0x08 /* Private */,
       4,    0,  156,    2, 0x08 /* Private */,
       5,    0,  157,    2, 0x08 /* Private */,
       6,    0,  158,    2, 0x08 /* Private */,
       7,    0,  159,    2, 0x08 /* Private */,
       8,    1,  160,    2, 0x08 /* Private */,
      10,    1,  163,    2, 0x08 /* Private */,
      12,    0,  166,    2, 0x08 /* Private */,
      13,    1,  167,    2, 0x08 /* Private */,
      15,    0,  170,    2, 0x08 /* Private */,
      16,    0,  171,    2, 0x08 /* Private */,
      17,    0,  172,    2, 0x08 /* Private */,
      18,    0,  173,    2, 0x08 /* Private */,
      19,    0,  174,    2, 0x08 /* Private */,
      20,    0,  175,    2, 0x08 /* Private */,
      21,    1,  176,    2, 0x08 /* Private */,
      22,    0,  179,    2, 0x08 /* Private */,
      23,    1,  180,    2, 0x08 /* Private */,
      24,    0,  183,    2, 0x08 /* Private */,
      25,    0,  184,    2, 0x08 /* Private */,
      26,    0,  185,    2, 0x08 /* Private */,
      27,    1,  186,    2, 0x08 /* Private */,
      29,    1,  189,    2, 0x08 /* Private */,
      30,    0,  192,    2, 0x08 /* Private */,
      31,    0,  193,    2, 0x08 /* Private */,
      32,    0,  194,    2, 0x08 /* Private */,
      33,    0,  195,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    9,
    QMetaType::Void, QMetaType::Int,   11,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   11,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPoint,   28,
    QMetaType::Void, QMetaType::QPoint,   28,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MainWindow *_t = static_cast<MainWindow *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->cancelCloseAction(); break;
        case 1: _t->saveCurrentConfig(); break;
        case 2: _t->saveConfigAsFile(); break;
        case 3: _t->loadConfigFromFile(); break;
        case 4: _t->showAboutPage(); break;
        case 5: _t->enableApplyButton(); break;
        case 6: _t->updateResamplerLabel((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->updatePeriodSizeEdit((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->updatePeriodSizeSlider(); break;
        case 9: _t->updatePeriodCountEdit((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->updatePeriodCountSlider(); break;
        case 11: _t->selectQuadDecoderFile(); break;
        case 12: _t->select51DecoderFile(); break;
        case 13: _t->select61DecoderFile(); break;
        case 14: _t->select71DecoderFile(); break;
        case 15: _t->select3D71DecoderFile(); break;
        case 16: _t->updateJackBufferSizeEdit((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 17: _t->updateJackBufferSizeSlider(); break;
        case 18: _t->updateHrtfModeLabel((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 19: _t->addHrtfFile(); break;
        case 20: _t->removeHrtfFile(); break;
        case 21: _t->updateHrtfRemoveButton(); break;
        case 22: _t->showEnabledBackendMenu((*reinterpret_cast< QPoint(*)>(_a[1]))); break;
        case 23: _t->showDisabledBackendMenu((*reinterpret_cast< QPoint(*)>(_a[1]))); break;
        case 24: _t->selectOSSPlayback(); break;
        case 25: _t->selectOSSCapture(); break;
        case 26: _t->selectSolarisPlayback(); break;
        case 27: _t->selectWaveOutput(); break;
        default: ;
        }
    }
}

const QMetaObject MainWindow::staticMetaObject = {
    { &QMainWindow::staticMetaObject, qt_meta_stringdata_MainWindow.data,
      qt_meta_data_MainWindow,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_MainWindow.stringdata0))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 28)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 28;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
